@@ -1,10 +1,6 @@
 package Carp::Always::Color;
-BEGIN {
-  $Carp::Always::Color::AUTHORITY = 'cpan:DOY';
-}
-{
-  $Carp::Always::Color::VERSION = '0.07';
-}
+our $AUTHORITY = 'cpan:DOY';
+$Carp::Always::Color::VERSION = '0.08';
 use strict;
 use warnings;
 # ABSTRACT: Carp::Always, but with color
@@ -22,13 +18,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Carp::Always::Color - Carp::Always, but with color
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -96,7 +94,7 @@ Jesse Luehrs <doy at tozt dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Jesse Luehrs.
+This software is copyright (c) 2016 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
