@@ -1,10 +1,6 @@
 package Carp::Always::Color::Term;
-BEGIN {
-  $Carp::Always::Color::Term::AUTHORITY = 'cpan:DOY';
-}
-{
-  $Carp::Always::Color::Term::VERSION = '0.07';
-}
+our $AUTHORITY = 'cpan:DOY';
+$Carp::Always::Color::Term::VERSION = '0.08';
 use strict;
 use warnings;
 use Carp::Always 0.10;
@@ -48,13 +44,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Carp::Always::Color::Term - Carp::Always, but with terminal color
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -75,7 +73,7 @@ Jesse Luehrs <doy at tozt dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Jesse Luehrs.
+This software is copyright (c) 2016 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
